package com.caimei365.user.mapper;

import com.caimei365.user.model.dto.ClubTemporaryDto;
import com.caimei365.user.model.po.ServiceProviderPo;
import com.caimei365.user.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/24
 */
@Mapper
public interface SellerMapper {
    /**
     * 根据手机号获取协销
     *
     * @param mobile 手机号
     * @return UserLoginVo
     */
    UserLoginVo getLoginSellerByMobile(String mobile);

    /**
     * 更新协销
     *
     * @param userId
     * @param openId
     * @param unionId
     */
    void updateServiceProviderByUserId(Integer userId, String openId, String unionId);

    /**
     * 更新协销信息
     */
    Integer setSellerHome(ServiceProviderPo serviceProviderPo);
    /**
     * 更新协销头像
     */
    Integer setSellerUserHome(@Param("userId")Integer userId, @Param("image")String image);

    /**
     * 查询待注册机构数据
     *
     * @param userId
     * @param searchName
     * @return
     */
    List<ClubTemporaryVo> findClubTemporary(@Param("userId") Integer userId, @Param("searchName") String searchName);

    /**
     * 修改待注册机构数据
     *
     * @param temporaryDto
     */
    void updateClubTemporary(ClubTemporaryDto temporaryDto);

    /**
     * 删除待注册机构数据
     *
     * @param id
     */
    void deleteTemporaryClub(Integer id);

    List<ClubVo> findClubs(@Param("serviceProviderId") Integer serviceProviderId, @Param("status") Integer status, @Param("name") String name, @Param("userIdentity") Integer userIdentity, @Param("type") Integer type, @Param("serviceIds") List<Integer> serviceIds);

    /***
     * 功能描述: 机构活跃分析用户登录数量
     * @auther: Kaick
     * @date: 2023/8/30 15:25
     * @param spID
     * @return [spID]
     */
    Map<String, Object> findSpUserLoginSum(@Param("spID") String spID);

    Integer findOrderNum(ClubVo club);

    /**
     * 所有的机构列表
     */
    List<ClubVo> getAllClubList(String searchWord);

    /**
     * 协销信息
     */
    ServiceProviderPo getSellerByUserId(Integer userId);

    Integer findManager(String mobile);

    Integer findManagerByUser(Integer userId);

    Integer findLeaderId(Integer userId);

    Integer findLeaderIdByServiceId(Integer serviceProviderId);

    Integer findmanagerIdByServiceId(Integer serviceProviderId);

    List<Integer> findServiceIds(Integer serviceProviderId);

    List<Integer> findAllServiceIds(Integer serviceProviderId);

    List<ServiceProviderVo> findServices(@Param("spId")Integer spId,@Param("status")Integer status);

    List<ServiceProviderVo> findAllServices(@Param("spId")Integer spId,@Param("status")Integer status);

    String getBehaviorRecordYesterdayPageLabel(@Param("spId") Integer spId,@Param("clubId") Integer clubId,@Param("accessTime")String accessTime);

    List<CmBehaviorRecordVo> getBehaviorRecordYesterdayClubFrom(@Param("spId") Integer spId, @Param("clubId") Integer clubId, @Param("accessTime")String accessTime);

    List<CmBehaviorRecordVo> getBehaviorRecordYesterdayClub(@Param("spId") Integer spId,@Param("accessTime")String accessTime);
}
