package com.caimei365.user.service;

import com.caimei365.user.model.po.SysDict;
import com.caimei365.user.model.vo.SysDictVO;

import java.util.List;

/**
 * 字典Service接口
 *
 * @author Kaick
 * @date 2023-07-14
 */
public interface SysDictService
{
    /**
     * 查询字典
     *
     * @param id 字典主键
     * @return 字典
     */
    public SysDictVO getSysDictById(String id);

    /**
     * 查询字典Id
     *
     * @param sysDict 字典主键
     * @return String
     */
    public String getById(SysDict sysDict);

    /**
     * 查询字典Ids
     *
     * @param sysDict 字典
     * @return List<String>
     */
    public List<String> getByIds(SysDict sysDict);

    /**
     * 查询字典
     *
     * @param sysDict 字典
     * @return 字典
     */
    public SysDictVO getBySysDict(SysDict sysDict);

    /**
     * 查询字典列表
     *
     * @param sysDict 字典
     * @return 字典集合
     */
    public List<SysDictVO> getSysDictList(SysDict sysDict);
    /**
     * 查询字典记录总数
     *
     * @param sysDict 字典
     * @return 字典Integer
     */
    public int getSysDictCount(SysDict sysDict);

    /**
     * 新增字典
     *
     * @param sysDict 字典
     * @return 结果
     */
    public int addSysDict(SysDict sysDict);

    /**
     * 修改字典
     *
     * @param sysDict 字典
     * @return 结果
     */
    public int updateSysDict(SysDict sysDict);

    /**
     * 批量删除字典
     *
     * @param ids 需要删除的字典主键集合
     * @return 结果
     */
    public int delSysDictByIds(String[] ids);

    /**
     * 删除字典信息
     *
     * @param id 字典主键
     * @return 结果
     */
    public int delSysDictById(String id);

    /**
     * 批量新增字典
     *
     * @param sysDictList 字典列表
     * @return 结果
     */
    public void batchAddSysDict(List<SysDict> sysDictList);

    /**
     * 批量修改字典
     *
     * @param sysDictList 字典列表
     * @return 结果
     */
    public void batchUpdateSysDict(List<SysDict> sysDictList);
}
