package com.caimei365.user.service.impl;

import java.util.Date;
import java.util.List;
import java.util.Map;

import com.caimei365.user.components.CommonService;
import com.caimei365.user.components.RedisService;
import com.caimei365.user.components.WeChatService;
import com.caimei365.user.mapper.BaseMapper;
import com.caimei365.user.mapper.CmDistributionMapper;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.LoginCodeDto;
import com.caimei365.user.model.po.CmDistribution;
import com.caimei365.user.model.po.CmUser;
import com.caimei365.user.model.vo.UserLoginVo;
import com.caimei365.user.service.CmDistributionService;
import com.caimei365.user.service.RemoteCallService;
import com.caimei365.user.utils.CodeUtil;
import com.caimei365.user.utils.DateUtil;
import com.caimei365.user.utils.JwtUtil;
import com.caimei365.user.utils.Md5Util;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.http.client.utils.DateUtils;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;

/**
 * distributionService业务层处理
 *
 * @author Kaick
 * @date 2023-09-25
 */
@Slf4j
@Service
public class CmDistributionServiceImpl implements CmDistributionService {
    @Resource
    private RedisService redisService;
    @Resource
    private BaseMapper baseMapper;
    @Resource
    private CmDistributionMapper cmDistributionMapper;
    @Resource
    private CommonService commonService;
    @Resource
    private RemoteCallService remoteCallService;
    /**
     * 通过对象查询distribution列表
     *
     * @param cmDistribution distribution
     * @return distribution
     */
    @Override
    public List<CmDistribution> getCmDistributionList(CmDistribution cmDistribution) {
        return cmDistributionMapper.getCmDistributionList(cmDistribution);
    }


    /**
     * 通过对象查询distribution
     *
     * @param cmDistribution distribution
     * @return distribution
     */
    @Override
    public CmDistribution getByCmDistribution(CmDistribution cmDistribution) {
        return cmDistributionMapper.getByCmDistribution(cmDistribution);
    }

    /**
     * 通过对象查询distribution
     *
     * @return distribution
     */
    @Override
    public CmDistribution getCmDistributionById(String id) {
        return cmDistributionMapper.getCmDistributionById(id);
    }


    /**
     * 新增distribution
     *
     * @param cmDistribution distribution
     * @return 结果
     */
    @Override
    public int addCmDistribution(CmDistribution cmDistribution) {
        cmDistribution.linkMan(cmDistribution.name());
        CmUser cmUser = new CmUser();
        cmUser.setMobile(cmDistribution.mobile());
        cmUser.setBindMobile(cmDistribution.mobile());
        cmUser.setServiceProviderStatus(cmDistribution.status());
        cmUser.setRealName(cmDistribution.name());
        cmUser.setUserName(cmDistribution.name());
        cmUser.setName(cmDistribution.name());
        cmUser.setAuditStatus("1");
        cmUser.setAuditTime(DateUtil.formatDateTime(new Date()));
        if (StringUtils.isBlank(cmDistribution.id())) {
            String password=(char)(Math.random()*26+'A')+ CodeUtil.generateCodeInt(7);
            cmUser.setUserOrganizeID("0");
            cmUser.setMobile(cmDistribution.mobile());
            cmUser.setBindMobile(cmDistribution.mobile());
            cmUser.setUserIdentity("7");//外部协销
            cmUser.setRegisterUserTypeID("32");//协销
            cmUser.setRegisterTime(DateUtil.formatDateTime(new Date()));
            cmUser.setValidFlag("1");
            CmDistribution cmDistributionByParentId = cmDistributionMapper.getCmDistributionById(String.valueOf(cmDistribution.parentId()));
            cmDistribution.parentIds(cmDistributionByParentId.parentIds() + "," + cmDistribution.parentId());
            cmDistribution.corporateName(cmDistributionByParentId.corporateName());
            cmDistribution.password(Md5Util.md5(password));
            cmUser.setPassword(cmDistribution.password());
            baseMapper.addUser(cmUser);
//            cmUser.setServiceProviderID(Integer.valueOf(cmDistribution.id()));
            cmDistribution.userId(Integer.valueOf(cmUser.getUserID()));
            cmDistribution.addTime(new Date());
            String content = "【分销系统】您的分销系统登录账号 ："+cmDistribution.mobile()+"，密码："+password;
            if (cmDistribution.mobile()!= null && cmDistribution.mobile() != "") {
                remoteCallService.remoteSendSms(0, 1, cmDistribution.mobile(), content);
            }
            return cmDistributionMapper.addCmDistribution(cmDistribution);
        } else {
            cmDistributionMapper.updateCmDistribution(cmDistribution);
            cmUser.setUserID(String.valueOf(cmDistribution.userId()));
            return baseMapper.updateUser(cmUser);
        }
    }

    /**
     * 修改distribution
     *
     * @param cmDistribution distribution
     * @return 结果
     */
    @Override
    public int updateCmDistribution(CmDistribution cmDistribution) {
        cmDistribution.updateTime(new Date());
        if (StringUtils.isNotBlank(cmDistribution.image())) {
            baseMapper.updateImageByUserId(cmDistribution.image(), cmDistribution.userId());
        }
        if (StringUtils.isNotBlank(cmDistribution.password())) {
            baseMapper.updatePasswordByUserId(cmDistribution.password(), cmDistribution.userId());
        }
        if (null!=cmDistribution.status()) {
            baseMapper.updateUser(new CmUser()
                    .userID(String.valueOf(cmDistribution.userId()))
                    .validFlag(cmDistribution.status()==90?"1":"0"));
        }
        return cmDistributionMapper.updateCmDistribution(cmDistribution);
    }

    /**
     * 协销登录(手机号，密码)
     *
     * @param mobile   手机号
     * @param password 密码
     * @return UserLoginVo
     */
    @Override
    public ResponseJson<UserLoginVo> passwordLogin(String mobile, String password) {
        if (StringUtils.isBlank(mobile) || StringUtils.isBlank(password)) {
            return ResponseJson.error("请输入账号密码", null);
        }
        UserLoginVo distribution = cmDistributionMapper.getLoginDistributionByMobile(mobile);
        if (null != distribution) {
            String key = "login-" + distribution.getUserId();
            boolean exists = redisService.exists(key);
            //如果30分钟内输入错误记录>=5,return该账号暂时被冻结，请（30-最前一次时间）分钟后重试或直接修改密码
            if (exists) {
                String val = (String) redisService.get(key);
                String[] split = val.split(",");
                int count = Integer.parseInt(split[0]);
                if (count >= 5) {
                    long s = Long.parseLong(split[1]);
                    int l = (int) Math.floor((System.currentTimeMillis() - s) / 1000 / 60);
                    return ResponseJson.error("该账号暂时被冻结，请" + (30 - l) + "分钟后重试或直接修改密码", null);
                }
            }
            // 比对密码
            if (Md5Util.md5(password).equals(distribution.getPassword())) {
                if (distribution.getServiceStatus().equals(90)) {
                    // 生成token
                    String token = JwtUtil.createToken(distribution.getUserId());
                    // 为了过期续签，将token存入redis，并设置超时时间
                    redisService.set(token, token, JwtUtil.getExpireTime());
                    distribution.setToken(token);
                    log.info("分销人员账号密码登录");
                    return ResponseJson.success(distribution);
                } else {
                    return ResponseJson.error("登录账号已下线，请联系客服", null);
                }
            } else {
                // 增加一次错误输入密码记录，30分钟内连续五次冻结
                if (exists) {
                    String val = (String) redisService.get(key);
                    String[] split = val.split(",");
                    int count = Integer.parseInt(split[0]);
                    if (count < 5) {
                        count++;
                        String va = count + "," + System.currentTimeMillis();
                        redisService.set(key, va);
                    }
                    if (count >= 5) {
                        redisService.set(key, 5 + "," + System.currentTimeMillis(), 1800L);
                    }
                } else {
                    String val = 1 + "," + System.currentTimeMillis();
                    redisService.set(key, val);
                }
            }
        }
        return ResponseJson.error("账户名与密码不匹配，请重新输入", null);
    }


    /**
     * 分销人员登录验证码登录
     *
     * @param loginCodeDto
     * @return
     */
    @Override
    public ResponseJson<UserLoginVo> organizeCodeLogin(LoginCodeDto loginCodeDto) {
        String mobile = loginCodeDto.getMobile();
        String code = loginCodeDto.getCode();
        if (StringUtils.isBlank(mobile)) {
            return ResponseJson.error("请输入手机号", null);
        }
        if (StringUtils.isBlank(code)) {
            return ResponseJson.error("请输入验证码", null);
        }
        // 判断redis中是否存在
        boolean exists = redisService.exists("code:" + mobile);
        if (exists) {
            // 查看验证码是否过期
            long expireTime = redisService.getExpireTime("code:" + mobile);
            if (expireTime < 0) {
                return ResponseJson.error(-1, "验证码已失效，请重新获取", null);
            }
            // 获取redis手机短信验证码
            Object randomCode = redisService.get("code:" + mobile);

            if (!ObjectUtils.isEmpty(randomCode)) {
                if (code.equals(randomCode.toString())) {
                    redisService.remove("code:" + mobile);
                    // 根据手机号获取分销人员
                    UserLoginVo distribution = cmDistributionMapper.getLoginDistributionByMobile(mobile);
                    if (null!=distribution&&distribution.getServiceStatus().equals(90)) {
                        // 生成token
                        String token = JwtUtil.createToken(distribution.getUserId());
                        // 为了过期续签，将token存入redis，并设置超时时间
                        redisService.set(token, token, JwtUtil.getExpireTime());
                        distribution.setToken(token);
                        log.info("分销人员账号密码登录");
                        return ResponseJson.success(distribution);
                    } else {
                        return ResponseJson.error("登录账号已下线，请联系客服", null);
                    }
                } else {
                    return ResponseJson.error(-1, "验证码错误，请确认验证码输入", null);
                }
            } else {
                return ResponseJson.error(-1, "验证码错误, 请重新获取", null);
            }
        }
        return ResponseJson.error(-1, "请获短信取验证码", null);
    }

    /**
     * 分销人员登录验证码登录
     *
     * @param loginCodeDto
     * @return
     */
    @Override
    public ResponseJson organizeClubCodeLogin(LoginCodeDto loginCodeDto ,String userId) {
        String mobile = loginCodeDto.getMobile();
        String code = loginCodeDto.getCode();
        if (StringUtils.isBlank(mobile)) {
            return ResponseJson.error("请输入手机号", null);
        }
        if (StringUtils.isBlank(code)) {
            return ResponseJson.error("请输入验证码", null);
        }
        // 判断redis中是否存在
        boolean exists = redisService.exists("code:" + mobile);
        if (exists) {
            // 查看验证码是否过期
            long expireTime = redisService.getExpireTime("code:" + mobile);
            if (expireTime < 0) {
                return ResponseJson.error(-1, "验证码已失效，请重新获取", null);
            }
            // 获取redis手机短信验证码
            Object randomCode = redisService.get("code:" + mobile);

            if (!ObjectUtils.isEmpty(randomCode)) {
                if (code.equals(randomCode.toString())) {
                    redisService.remove("code:" + mobile);
                    // 根据手机号获取分销人员
                    CmUser user = baseMapper.getByUser(new CmUser().userIdentity("8").userID(userId).bindMobile(mobile));
                    if (null!=user) {
                        String password=(char)(Math.random()*26+'A')+CodeUtil.generateCodeInt(7);
                        baseMapper.updateUser(new CmUser()
                                .userID(userId)
                                .validFlag("1")
                                .clubStatus(90)
                                .password(Md5Util.md5(password))
                        );
                        baseMapper.updateClubStatus(Integer.valueOf(userId),90);
                        // 发送短信
                        String content = "【分销系统】亲爱的买家，您好，系统根据您下单时的手机号默认给您生成了登录账号与密码，账号："+mobile+"，密码："+password+"，您可通过手机号与密码或验证码登录分销系统查看您的订单状态";
                        boolean smsFlag = remoteCallService.remoteSendSms(0, 1, mobile, content);
                        if (!smsFlag) {
                            // 短信发送失败重试一次
                            remoteCallService.remoteSendSms(0, 1, mobile, content);
                        }
                        // 生成token
                        String token = JwtUtil.createToken(Integer.valueOf(userId));
                        // 为了过期续签，将token存入redis，并设置超时时间
                        redisService.set(token, token, JwtUtil.getExpireTime());
                        return ResponseJson.success(null,token);
                    } else {
                        return ResponseJson.error("该手机号暂未注册", null);
                    }
                } else {
                    return ResponseJson.error(-1, "验证码错误，请确认验证码输入", null);
                }
            } else {
                return ResponseJson.error(-1, "验证码错误, 请重新获取", null);
            }
        }
        return ResponseJson.error(-1, "请获短信取验证码", null);
    }

    /**
     * 分销人员登录验证码登录
     *
     * @param cmDistribution
     * @return
     */
    @Override
    public ResponseJson setPassword(CmDistribution cmDistribution, String code) {
        String mobile = cmDistribution.mobile();
        if (StringUtils.isBlank(mobile)) {
            return ResponseJson.error("请输入手机号", null);
        }
        if (StringUtils.isBlank(code)) {
            return ResponseJson.error("请输入验证码", null);
        }
        UserLoginVo userBy = cmDistributionMapper.getLoginDistributionByMobile(mobile);
        if (null==userBy) {
            return ResponseJson.error("该手机号暂未注册", null);
        }
        // 判断redis中是否存在
        boolean exists = redisService.exists("code:" + mobile);
        if (exists) {
            // 查看验证码是否过期
            long expireTime = redisService.getExpireTime("code:" + mobile);
            if (expireTime < 0) {
                return ResponseJson.error(-1, "验证码已失效，请重新获取", null);
            }
            // 获取redis手机短信验证码
            Object randomCode = redisService.get("code:" + mobile);

            if (!ObjectUtils.isEmpty(randomCode)) {
                if (code.equals(randomCode.toString())) {
                    redisService.remove("code:" + mobile);
                    updateCmDistribution(new CmDistribution()
                            .userId(userBy.getUserId())
                            .password(Md5Util.md5(cmDistribution.password()))
                    );
                    return ResponseJson.success();
                } else {
                    return ResponseJson.error(-1, "验证码错误，请确认验证码输入", null);
                }
            } else {
                return ResponseJson.error(-1, "验证码错误, 请重新获取", null);
            }
        }
        return ResponseJson.error(-1, "请获短信取验证码", null);
    }
}


