package com.caimei365.user.service.impl;

import java.util.Date;
import java.util.List;

import com.caimei365.user.model.po.SysDict;
import com.caimei365.user.model.vo.SysDictVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.caimei365.user.mapper.SysDictMapper;
import com.caimei365.user.service.SysDictService;

/**
 * 字典Service业务层处理
 *
 * @author Kaick
 * @date 2023-07-14
 */
@Service
public class SysDictServiceImpl implements SysDictService
{
    @Autowired
    private SysDictMapper sysDictMapper;

    /**
     * 查询字典
     *
     * @param id 字典主键
     * @return 字典
     */
    @Override
    public SysDictVO getSysDictById(String id)
    {
        return sysDictMapper.getSysDictById(id);
    }

    /**
     * 查询字典Id
     *
     * @param sysDict 字典
     * @return String
     */
    @Override
    public String getById(SysDict sysDict)
    {
        return sysDictMapper.getById(sysDict);
    }

    /**
     * 查询字典Ids
     *
     * @param sysDict 字典
     * @return List<String>
     */
    @Override
    public List<String> getByIds(SysDict sysDict)
    {
        return sysDictMapper.getByIds(sysDict);
    }

    /**
     * 查询字典
     *
     * @param sysDict 字典
     * @return 字典
     */
    @Override
    public SysDictVO getBySysDict(SysDict sysDict)
    {
        return sysDictMapper.getBySysDict(sysDict);
    }

    /**
     * 查询字典列表
     *
     * @param sysDict 字典
     * @return 字典
     */
    @Override
    public List<SysDictVO> getSysDictList(SysDict sysDict)
    {
        return sysDictMapper.getSysDictList(sysDict);
    }
    /**
     * 查询字典记录总数
     *
     * @param sysDict 字典
     * @return 字典
     */
    @Override
    public int getSysDictCount(SysDict sysDict)
    {
        return sysDictMapper.getSysDictCount(sysDict);
    }

    /**
     * 新增字典
     *
     * @param sysDict 字典
     * @return 结果
     */
    @Override
    public int addSysDict(SysDict sysDict)
    {
        sysDict.setCreateDate(new Date());
        return sysDictMapper.addSysDict(sysDict);
    }

    /**
     * 修改字典
     *
     * @param sysDict 字典
     * @return 结果
     */
    @Override
    public int updateSysDict(SysDict sysDict)
    {
        sysDict.setUpdateDate(new Date());
        return sysDictMapper.updateSysDict(sysDict);
    }

    /**
     * 批量删除字典
     *
     * @param ids 需要删除的字典主键
     * @return 结果
     */
    @Override
    public int delSysDictByIds(String[] ids)
    {
        return sysDictMapper.updateDelSysDictByIds(ids,1);
        //return sysDictMapper.delSysDictByIds(ids);
    }

    /**
     * 删除字典信息
     *
     * @param id 字典主键
     * @return 结果
     */
    @Override
    public int delSysDictById(String id)
    {
        return sysDictMapper.updateSysDict(new SysDict().setId(id).setDelFlag("1"));
        //return sysDictMapper.delSysDictById(id);
    }

    /**
     * 批量新增字典
     *
     * @param sysDictList 字典列表
     * @return 结果
     */
    @Override
    public void batchAddSysDict(List<SysDict> sysDictList)
    {
            for (SysDict sysDict : sysDictList)
            {
                    sysDictMapper.addSysDict(sysDict);
            }
    }

    /**
     * 批量修改字典
     *
     * @param sysDictList 字典列表
     * @return 结果
     */
    @Override
    public void batchUpdateSysDict(List<SysDict> sysDictList)
    {
            for (SysDict sysDict : sysDictList)
            {
                   sysDictMapper.updateSysDict(sysDict);
            }
        }
    }
